@@ -1,4 +1,4 @@
-from Algorithms.doublylinkedlist import DoublyLinkedList as dll 
+from cacheall.Algorithms.doublylinkedlist import DoublyLinkedList as dll 
 # LRU cache class
 class LRUCache:
 
