@@ -7,7 +7,7 @@ from threading import Thread
 
 def threadf1(lock):
     print('Going to test the LRU Cache Implementation')
-    cache = LIFOCache(2,lock)
+    cache = FIFOCache(2,lock)
     cache.set(1, 10)
     cache.set(2, 20)
     print('Value for the key: 1 is {}'.format(cache.get(1))) 
@@ -22,7 +22,7 @@ def threadf1(lock):
 
 def threadf2(lock):
     print('Going to test the LRU Cache Implementation')
-    cache = LIFOCache(2,lock)
+    cache = FIFOCache(2,lock)
     cache.set(5, 10)
     cache.set(7, 20)
     cache.set(9,18)
